==> nats-server-2.10.19-rc.5-sources.jar: berlin/yuna/natsserver/config/NatsVersion.java <==
package berlin.yuna.natsserver.config;

public enum NatsVersion {

    V2_9_9("v2.9.9"),
    V2_9_8("v2.9.8"),
    V2_9_7("v2.9.7"),
    V2_9_6("v2.9.6"),
    V2_9_5("v2.9.5"),
    V2_9_4("v2.9.4"),
    V2_9_3("v2.9.3"),
    V2_9_25("v2.9.25"),
    V2_9_24("v2.9.24"),
    V2_9_23("v2.9.23"),
    V2_9_22("v2.9.22"),
    V2_9_21("v2.9.21"),
    V2_9_20("v2.9.20"),
    V2_9_2("v2.9.2"),
    V2_9_19("v2.9.19"),
    V2_9_18("v2.9.18"),
    V2_9_17("v2.9.17"),
    V2_9_16("v2.9.16"),
    V2_9_15("v2.9.15"),
    V2_9_14("v2.9.14"),
    V2_9_12("v2.9.12"),
    V2_9_11("v2.9.11"),
    V2_9_10("v2.9.10"),
    V2_9_1("v2.9.1"),
    V2_9_0("v2.9.0"),
    V2_8_4("v2.8.4"),
    V2_8_3("v2.8.3"),
    V2_8_2("v2.8.2"),
    V2_8_1("v2.8.1"),
    V2_8_0("v2.8.0"),
    V2_7_4("v2.7.4"),
    V2_7_3("v2.7.3"),
    V2_7_2("v2.7.2"),
    V2_7_1("v2.7.1"),
    V2_7_0_RC2("v2.7.0-rc2"),
    V2_7_0_RC1("v2.7.0-rc1"),
    V2_7_0("v2.7.0"),
    V2_6_6("v2.6.6"),
    V2_6_5("v2.6.5"),
    V2_6_4("v2.6.4"),
    V2_6_3("v2.6.3"),
    V2_6_2("v2.6.2"),
    V2_6_1("v2.6.1"),
    V2_6_0("v2.6.0"),
    V2_5_0("v2.5.0"),
    V2_4_0("v2.4.0"),
    V2_3_4("v2.3.4"),
    V2_3_3("v2.3.3"),
    V2_3_2("v2.3.2"),
    V2_3_1("v2.3.1"),
    V2_3_0("v2.3.0"),
    V2_2_6("v2.2.6"),
    V2_2_5("v2.2.5"),
    V2_2_4("v2.2.4"),
    V2_2_3("v2.2.3"),
    V2_2_2("v2.2.2"),
    V2_2_1("v2.2.1"),
    V2_2_0("v2.2.0"),
    V2_1_9("v2.1.9"),
    V2_1_8("v2.1.8"),
    V2_1_7("v2.1.7"),
    V2_1_6("v2.1.6"),
    V2_1_4("v2.1.4"),
    V2_1_2("v2.1.2"),
    V2_1_0("v2.1.0"),
    V2_11_0_PREVIEW_2("v2.11.0-preview.2"),
    V2_11_0_PREVIEW_1("v2.11.0-preview.1"),
    V2_11_0_DEV("v2.11.0-dev"),
    V2_10_9("v2.10.9"),
    V2_10_8("v2.10.8"),
    V2_10_7("v2.10.7"),
    V2_10_6("v2.10.6"),
    V2_10_5("v2.10.5"),
    V2_10_4("v2.10.4"),
    V2_10_3("v2.10.3"),
    V2_10_2("v2.10.2"),
    V2_10_18_RC_4("v2.10.18-RC.4"),
    V2_10_18_RC_3("v2.10.18-RC.3"),
    V2_10_18_RC_2("v2.10.18-RC.2"),
    V2_10_18_RC_1("v2.10.18-RC.1"),
    V2_10_18("v2.10.18"),
    V2_10_17_RC_9("v2.10.17-RC.9"),
    V2_10_17_RC_8("v2.10.17-RC.8"),
    V2_10_17_RC_7("v2.10.17-RC.7"),
    V2_10_17_RC_6("v2.10.17-RC.6"),
    V2_10_17_RC_5("v2.10.17-RC.5"),
    V2_10_17_RC_4("v2.10.17-RC.4"),
    V2_10_17_RC_3("v2.10.17-RC.3"),
    V2_10_17_RC_2("v2.10.17-RC.2"),
    V2_10_17_RC_1("v2.10.17-RC.1"),
    V2_10_17("v2.10.17"),
    V2_10_16("v2.10.16"),
    V2_10_14("v2.10.14"),
    V2_10_12("v2.10.12"),
    V2_10_11("v2.10.11"),
    V2_10_10("v2.10.10"),
    V2_10_1("v2.10.1"),
    V2_10_0("v2.10.0"),
    V2_0_4("v2.0.4"),
    V2_0_2("v2.0.2");

    final String value;

    NatsVersion(final String value) {
        this.value = value;
    }

    public String value() {
        return value;
    }
}

==> nats-server-2.10.22-sources.jar: berlin/yuna/natsserver/config/NatsVersion.java <==
package berlin.yuna.natsserver.config;

public enum NatsVersion {

    V2_9_9("v2.9.9"),
    V2_9_8("v2.9.8"),
    V2_9_7("v2.9.7"),
    V2_9_6("v2.9.6"),
    V2_9_5("v2.9.5"),
    V2_9_4("v2.9.4"),
    V2_9_3("v2.9.3"),
    V2_9_25("v2.9.25"),
    V2_9_24("v2.9.24"),
    V2_9_23("v2.9.23"),
    V2_9_22("v2.9.22"),
    V2_9_21("v2.9.21"),
    V2_9_20("v2.9.20"),
    V2_9_2("v2.9.2"),
    V2_9_19("v2.9.19"),
    V2_9_18("v2.9.18"),
    V2_9_17("v2.9.17"),
    V2_9_16("v2.9.16"),
    V2_9_15("v2.9.15"),
    V2_9_14("v2.9.14"),
    V2_9_12("v2.9.12"),
    V2_9_11("v2.9.11"),
    V2_9_10("v2.9.10"),
    V2_9_1("v2.9.1"),
    V2_9_0("v2.9.0"),
    V2_8_4("v2.8.4"),
    V2_8_3("v2.8.3"),
    V2_8_2("v2.8.2"),
    V2_8_1("v2.8.1"),
    V2_8_0("v2.8.0"),
    V2_7_4("v2.7.4"),
    V2_7_3("v2.7.3"),
    V2_7_2("v2.7.2"),
    V2_7_1("v2.7.1"),
    V2_7_0_RC2("v2.7.0-rc2"),
    V2_7_0_RC1("v2.7.0-rc1"),
    V2_7_0("v2.7.0"),
    V2_6_6("v2.6.6"),
    V2_6_5("v2.6.5"),
    V2_6_4("v2.6.4"),
    V2_6_3("v2.6.3"),
    V2_6_2("v2.6.2"),
    V2_6_1("v2.6.1"),
    V2_6_0("v2.6.0"),
    V2_5_0("v2.5.0"),
    V2_4_0("v2.4.0"),
    V2_3_4("v2.3.4"),
    V2_3_3("v2.3.3"),
    V2_3_2("v2.3.2"),
    V2_3_1("v2.3.1"),
    V2_3_0("v2.3.0"),
    V2_2_6("v2.2.6"),
    V2_2_5("v2.2.5"),
    V2_2_4("v2.2.4"),
    V2_2_3("v2.2.3"),
    V2_2_2("v2.2.2"),
    V2_2_1("v2.2.1"),
    V2_2_0("v2.2.0"),
    V2_1_9("v2.1.9"),
    V2_1_8("v2.1.8"),
    V2_1_7("v2.1.7"),
    V2_1_6("v2.1.6"),
    V2_1_4("v2.1.4"),
    V2_1_2("v2.1.2"),
    V2_1_0("v2.1.0"),
    V2_11_0_PREVIEW_2("v2.11.0-preview.2"),
    V2_11_0_PREVIEW_1("v2.11.0-preview.1"),
    V2_11_0_DEV("v2.11.0-dev"),
    V2_10_9("v2.10.9"),
    V2_10_8("v2.10.8"),
    V2_10_7("v2.10.7"),
    V2_10_6("v2.10.6"),
    V2_10_5("v2.10.5"),
    V2_10_4("v2.10.4"),
    V2_10_3("v2.10.3"),
    V2_10_22_RC_3("v2.10.22-RC.3"),
    V2_10_22_RC_2("v2.10.22-RC.2"),
    V2_10_22_RC_1("v2.10.22-RC.1"),
    V2_10_22("v2.10.22"),
    V2_10_21_RC_4("v2.10.21-RC.4"),
    V2_10_21_RC_3("v2.10.21-RC.3"),
    V2_10_21_RC_2("v2.10.21-RC.2"),
    V2_10_21_RC_1("v2.10.21-RC.1"),
    V2_10_21("v2.10.21"),
    V2_10_20("v2.10.20"),
    V2_10_2("v2.10.2"),
    V2_10_19_RC_6("v2.10.19-RC.6"),
    V2_10_19_RC_5("v2.10.19-RC.5"),
    V2_10_19_RC_4("v2.10.19-RC.4"),
    V2_10_19_RC_3("v2.10.19-RC.3"),
    V2_10_19_RC_2("v2.10.19-RC.2"),
    V2_10_19("v2.10.19"),
    V2_10_18_RC_4("v2.10.18-RC.4"),
    V2_10_18_RC_3("v2.10.18-RC.3"),
    V2_10_18_RC_2("v2.10.18-RC.2"),
    V2_10_18_RC_1("v2.10.18-RC.1"),
    V2_10_18("v2.10.18"),
    V2_10_17_RC_9("v2.10.17-RC.9"),
    V2_10_17_RC_8("v2.10.17-RC.8"),
    V2_10_17_RC_7("v2.10.17-RC.7");

    final String value;

    NatsVersion(final String value) {
        this.value = value;
    }

    public String value() {
        return value;
    }
}
